function rotMat = roty(angleDeg)
    % ROTY Rotation matrix about Y-axis
    % -----
    %
    % Syntax:
    %   rotMat = roty(angleDeg) returns the rotation matrix that rotates
    %   a point of an angle `angleDeg` (in degrees) around the Y-axis.
    %
    % Inputs:
    %   angleDeg: Angle of rotation, [deg]
    %
    % Outputs:
    %   rotMat  : 3x3 matrix for the rotation around Y-axis
    %
    % See also: rotx, rotz.
    %
    % <a href="https://gitlab.uliege.be/rotare/documentation">Complete documentation (online)</a>

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/rotare/rotare
    % Docs: https://gitlab.uliege.be/rotare/documentation
    % Issues: https://gitlab.uliege.be/rotare/rotare/-/issues
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    validateattributes(angleDeg, {'numeric'}, {'scalar'}, mfilename(), 'angleDeg', 1);

    rotMat = [cosd(angleDeg),  0,              sind(angleDeg)
              0,               1,              0
              -sind(angleDeg), 0,              cosd(angleDeg)];

end
